@@ -13,6 +13,10 @@ pub mod client;
 pub mod configuration;
 pub mod constants;
 pub mod domain;
+pub mod error;
+pub mod metrics;
+#[macro_use]
+mod macros;
 pub mod routes;
 pub mod startup;
 pub mod telemetry;
