@@ -6,13 +6,14 @@
 // copied, modified, or distributed except according to those terms.
 
 use auditor::configuration::get_configuration;
+use auditor::metrics::DatabaseMetricsWatcher;
 use auditor::startup::run;
 use auditor::telemetry::{get_subscriber, init_subscriber};
 use sqlx::postgres::PgPoolOptions;
 use std::net::TcpListener;
 
 #[tokio::main]
-async fn main() -> Result<(), std::io::Error> {
+async fn main() -> Result<(), anyhow::Error> {
     // Set up logging
     let subscriber = get_subscriber("AUDITOR".into(), "info".into(), std::io::stdout);
     init_subscriber(subscriber);
@@ -25,6 +26,14 @@ async fn main() -> Result<(), std::io::Error> {
         .connect_timeout(std::time::Duration::from_secs(2))
         .connect_lazy_with(configuration.database.with_db());
 
+    // Start background task
+    let db_metrics_watcher = DatabaseMetricsWatcher::new(connection_pool.clone(), &configuration)?;
+    let db_metrics_watcher_task = db_metrics_watcher.clone();
+    // TODO: Don't panic!
+    tokio::spawn(async move {
+        db_metrics_watcher_task.monitor().await.unwrap();
+    });
+
     // Create a TcpListener for a given address and port
     let address = format!(
         "{}:{}",
@@ -33,7 +42,7 @@ async fn main() -> Result<(), std::io::Error> {
     let listener = TcpListener::bind(address)?;
 
     // Start server
-    run(listener, connection_pool)?.await?;
+    run(listener, connection_pool, db_metrics_watcher)?.await?;
 
     Ok(())
 }
