@@ -10,17 +10,26 @@ use actix_web::{web, HttpResponse};
 use sqlx;
 use sqlx::PgPool;
 
+#[derive(thiserror::Error)]
+pub enum GetError {
+    #[error(transparent)]
+    UnexpectedError(#[from] anyhow::Error),
+}
+
+debug_for_error!(GetError);
+responseerror_for_error!(GetError, UnexpectedError => INTERNAL_SERVER_ERROR;);
+
 #[tracing::instrument(name = "Getting all records from database", skip(pool))]
-pub async fn get(pool: web::Data<PgPool>) -> HttpResponse {
-    match get_records(&pool).await {
-        Ok(records) => HttpResponse::Ok().json(records),
-        Err(_) => HttpResponse::InternalServerError().finish(),
-    }
+pub async fn get(pool: web::Data<PgPool>) -> Result<HttpResponse, GetError> {
+    let records = get_records(&pool)
+        .await
+        .map_err(GetError::UnexpectedError)?;
+    Ok(HttpResponse::Ok().json(records))
 }
 
 #[tracing::instrument(name = "Retrieving records from database", skip(pool))]
-pub async fn get_records(pool: &PgPool) -> Result<Vec<Record>, sqlx::Error> {
-    sqlx::query_as!(
+pub async fn get_records(pool: &PgPool) -> Result<Vec<Record>, anyhow::Error> {
+    Ok(sqlx::query_as!(
         Record,
         r#"SELECT
            record_id, site_id, user_id, group_id, components as "components: Vec<Component>",
@@ -30,8 +39,14 @@ pub async fn get_records(pool: &PgPool) -> Result<Vec<Record>, sqlx::Error> {
     )
     .fetch_all(pool)
     .await
-    .map_err(|e| {
-        tracing::error!("Failed to execute query: {:?}", e);
-        e
-    })
+    .map_err(GetRecordError)?)
 }
+
+pub struct GetRecordError(sqlx::Error);
+
+error_for_error!(GetRecordError);
+debug_for_error!(GetRecordError);
+display_for_error!(
+    GetRecordError,
+    "A database error was encountered while trying to get a record from the database."
+);
